@@ -212,11 +212,9 @@ MRSortIdentifyIncompatibleAssignments <- function(performanceTable, assignments,
     else
       stop(out)
     
-    solverStatus <- cplexAPI::getStatCPLEX(env,prob)
-    
     error <- TRUE
     
-    if ((cplexAPI::getStatCPLEX(env,prob) == 101) | (cplexAPI::getStatCPLEX(env,prob) == 102)){
+    if (cplexAPI::getStatCPLEX(env,prob) %in% c(1,5,15,17,19,20,101,102,115,121,123,125,129,130)){
       solution <- cplexAPI::solutionCPLEX(env,prob)$x
       
       varnames <- cplexAPI::getColNameCPLEX(env,prob, 0,length(solution)-1)
@@ -231,8 +229,6 @@ MRSortIdentifyIncompatibleAssignments <- function(performanceTable, assignments,
     
     solveMIPGLPK(lp)
     
-    solverStatus <- mipStatusGLPK(lp)
-    
     error <- TRUE
     
     if(mipStatusGLPK(lp)==5){
@@ -389,11 +385,10 @@ MRSortIdentifyIncompatibleAssignments <- function(performanceTable, assignments,
           else
             stop(out)
           
-          solverStatus <- cplexAPI::getStatCPLEX(env,prob)
-          
           error <- TRUE
           
-          if ((cplexAPI::getStatCPLEX(env,prob) == 101) | (cplexAPI::getStatCPLEX(env,prob) == 102)){
+          if (cplexAPI::getStatCPLEX(env,prob) %in% c(1,5,15,17,19,20,101,102,115,121,123,125,129,130)){
+            
             solution <- cplexAPI::solutionCPLEX(env,prob)$x
             
             varnames <- cplexAPI::getColNameCPLEX(env,prob, 0,length(solution)-1)
@@ -408,8 +403,6 @@ MRSortIdentifyIncompatibleAssignments <- function(performanceTable, assignments,
           
           solveMIPGLPK(lp)
           
-          solverStatus <- mipStatusGLPK(lp)
-          
           error <- TRUE
           
           if(mipStatusGLPK(lp)==5){
@@ -463,9 +456,9 @@ MRSortIdentifyIncompatibleAssignments <- function(performanceTable, assignments,
       incompatibleSetSize <- incompatibleSetSize + 1
     }
     
-    return(list(incompatibleSets = incompatibleSets, status = 1))
+    return(list(incompatibleSets = incompatibleSets, solverStatus = 'Success'))
     
   }
   else
-    return(list(status = 0))
+    return(list(solverStatus = 'Failed'))
 }
